@@ -16,7 +16,7 @@ from . import probabilities as prob
 from .errors import KineticlibError
 
 
-def diss_integral_rigid_sphere(T: float, deg: int, idata: np.ndarray, molecule: Molecule, i: int,
+def diss_integral_rigid_sphere(T: float, deg: int, idata: np.ndarray, molecule: MoleculeSTS, i: int,
                                center_of_mass: bool=True, vl_dependent: bool=True, nokt: bool=False) -> float:
     """Calculates the generalized dissociation omega integral either using the rigid sphere model or the rigid sphere
     model depending on the relative energy along the center-of-mass line
@@ -231,6 +231,7 @@ def vv_collisions(T: float, T1_1: float, T1_2: float, idata: np.ndarray, molecul
 
 def dE_rot_sq(T: float, idata: np.ndarray, molecule: MoleculeSTS, full_integral: bool=True, nokt: bool=False) -> float:
     """Calculates either the partial averaging of the squared change in rotational energy
+    over all one-quantum rotational transitions
     :math:`\\left<\\left(\\Delta \\mathcal{E}^{rot}_{c}\\right)^{2}\\right>_{part}`
     or the full averaging of the same quantity :math:`\\left<\\left(\\Delta \\mathcal{E}^{rot}_{c}\\right)^{2}\\right>`,
     considering all one-quantum transitions to be equiprobable
@@ -253,24 +254,15 @@ def dE_rot_sq(T: float, idata: np.ndarray, molecule: MoleculeSTS, full_integral:
     float
         The calculated averaging
     """
-    f = lambda j: (2 * molecule.rot_energy(j) * molecule.rot_energy(j + 1)
-                   + molecule.rot_energy(j) ** 2
-                   + molecule.rot_energy(j + 1) ** 2) * molecule.rot_exp(j, T)
-    tmp = integrate.quad(f, 0, molecule.num_rot - 1)[0]
-    f = lambda j: (2 * molecule.rot_energy(j) * molecule.rot_energy(j - 1)
-                   + molecule.rot_energy(j) ** 2
-                   + molecule.rot_energy(j - 1) ** 2) * molecule.rot_exp(j, T)
-    tmp += integrate.quad(f, 1, molecule.num_rot)[0]
-    if full_integral is False:
-        return tmp * 0.5 / (molecule.Z_rot(T) * ((constants.k * T) ** 2) * molecule.num_rot)
-    else:
-        return tmp * 0.5 / (molecule.Z_rot(T) * ((constants.k * T) ** 2) * molecule.num_rot)\
-               * elastic_integral(T, 0, idata, nokt=nokt)
+    return raw_dE_rot_sq(T, idata, molecule.Z_rot(T), molecule.rot_symmetry, molecule.rot_const, molecule.num_rot,
+                         full_integral, nokt)
 
 
-def dE_rot_single(T: float, idata: np.ndarray, molecule: MoleculeSTS, full_integral: bool=True, nokt: bool=False) -> float:
+def dE_rot_single(T: float, idata: np.ndarray, molecule: MoleculeSTS, full_integral: bool=True,
+                  nokt: bool=False) -> float:
     """Calculates either the partial averaging of the squared change in rotational energy
-    :math`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\right>_{part}`
+    over all one-quantum rotational transitions
+    :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\right>_{part}`
     or the full averaging of the same quantity :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\right>`,
     considering all one-quantum transitions to be equiprobable
 
@@ -292,20 +284,14 @@ def dE_rot_single(T: float, idata: np.ndarray, molecule: MoleculeSTS, full_integ
     float
         The calculated averaging
     """
-    f = lambda j: (molecule.rot_energy(j) - molecule.rot_energy(j + 1)) * molecule.rot_exp(j, T)
-    tmp = integrate.quad(f, 0, molecule.num_rot - 1)[0]
-    f = lambda j: (molecule.rot_energy(j) - molecule.rot_energy(j - 1)) * molecule.rot_exp(j, T)
-    tmp += integrate.quad(f, 1, molecule.num_rot)[0]
-    if full_integral is False:
-        return tmp * 0.5 / (molecule.Z_rot(T) * constants.k * T * molecule.num_rot)
-    else:
-        return tmp * 0.5 / (molecule.Z_rot(T) * constants.k * T * molecule.num_rot) * elastic_integral(T, 0, idata,
-                                                                                                       nokt=nokt)
+    return raw_dE_rot_single(T, idata, molecule.Z_rot(T), molecule.rot_symmetry, molecule.rot_const, molecule.num_rot,
+                             full_integral, nokt)
 
 
 def dE_rot_c_dE_rot_d(T: float, idata: np.ndarray, molecule1: MoleculeSTS, molecule2: MoleculeSTS,
                       full_integral: bool=True, nokt: bool=False) -> float:
     """Calculates either the partial averaging of the squared change in rotational energy
+    over all one-quantum rotational transitions
     :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\Delta \\mathcal{E}^{rot}_{d}\\right>_{part}`
     or the full averaging of the same quantity
     :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\Delta \\mathcal{E}^{rot}_{d}\\right>`,
@@ -331,12 +317,15 @@ def dE_rot_c_dE_rot_d(T: float, idata: np.ndarray, molecule1: MoleculeSTS, molec
     float
         The calculated averaging
     """
-    return dE_rot_single(T, idata, molecule1, full_integral, nokt) * dE_rot_single(T, idata, molecule2, False)
+    return raw_dE_rot_c_dE_rot_d(T, idata, molecule1.Z_rot(T), molecule2.Z_rot(T), molecule1.rot_symmetry,
+                                 molecule2.rot_symmetry, molecule1.rot_const, molecule2.rot_const, molecule1.num_rot,
+                                 molecule2.num_rot, full_integral, nokt)
 
 
 def dE_rot_dE_rot_full(T: float, idata: np.ndarray, molecule1: MoleculeSTS, molecule2: MoleculeSTS,
                        full_integral: bool=True, nokt: bool=False) -> float:
     """Calculates either the partial averaging of the squared change in rotational energy
+    over all one-quantum rotational transitions
     :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\left(\\Delta \\mathcal{E}^{rot}_{c}
     + \\Delta \\mathcal{E}^{rot}_{d} \\right)\\right>_{part}`
     or the full averaging of the same quantity
@@ -364,8 +353,9 @@ def dE_rot_dE_rot_full(T: float, idata: np.ndarray, molecule1: MoleculeSTS, mole
     float
         The calculated averaging
     """
-    return dE_rot_sq(T, idata, molecule1, full_integral, nokt)\
-           + dE_rot_single(T, idata, molecule1, full_integral, nokt) * dE_rot_single(T, idata, molecule2, False)
+    return raw_dE_rot_dE_rot_full(T, idata, molecule1.Z_rot(T), molecule2.Z_rot(T), molecule1.rot_symmetry,
+                                  molecule2.rot_symmetry, molecule1.rot_const, molecule2.rot_const, molecule1.num_rot,
+                                  molecule2.num_rot, full_integral, nokt)
 
 
 def raw_diss_integral_rigid_sphere(T: float, deg: int, idata: np.ndarray, molecule_vibr: float,
@@ -698,4 +688,211 @@ def raw_vv_collisions(T: float, idata: np.ndarray, Z_vibr1: float, Z_vibr2: floa
             result[10] -= molecule_vibr_exp_array1[i + 1] * molecule_vibr_exp_array2[k] * cs
             result[11] -= molecule_vibr_exp_array1[i + 1] * molecule_vibr_exp_array2[k] * cs
 
-    return result / Z
\ No newline at end of file
+    return result / Z
+
+
+def raw_dE_rot_sq(T: float, idata: np.ndarray, Z_rot: float, molecule_rot_symmetry: float, molecule_rot_const: float,
+                  molecule_num_rot: int, full_integral: bool=True, nokt: bool=False) -> float:
+    """Calculates either the partial averaging of the squared change in rotational energy
+    over all one-quantum rotational transitions
+    :math:`\\left<\\left(\\Delta \\mathcal{E}^{rot}_{c}\\right)^{2}\\right>_{part}`
+    or the full averaging of the same quantity :math:`\\left<\\left(\\Delta \\mathcal{E}^{rot}_{c}\\right)^{2}\\right>`,
+    considering all one-quantum transitions to be equiprobable, *raw* version
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    idata : 1-D array-like
+        the array of interaction data
+    Z_rot : float
+        the value of the rotational partition function of the molecule
+    molecule_rot_symmetry : float
+        should equal 2.0 if the molecule is homonuclear and 1.0 otherwise
+    molecule_rot_const : float
+        The quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
+        inertia of the molecule
+    molecule_num_rot : int
+        the amount of rotational levels in the molecule
+    full_integral : bool
+        if True, the full averaging is calculated, if false, the partial averaging is calculated, defaults to True
+    nokt : bool, optional
+        if True and full_integral is True, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to False
+
+    Returns
+    -------
+    float
+        The calculated averaging
+    """
+    f = lambda j: (2 * j * (j + 1) * molecule_rot_const * (j + 1) * (j + 2) * molecule_rot_const
+                   + (j * (j + 1) * molecule_rot_const) ** 2
+                   + ((j + 1) * (j + 2) * molecule_rot_const) ** 2)\
+                  * ((2.0 * j + 1.0) / molecule_rot_symmetry)\
+                  * np.exp(-j * (j + 1) * molecule_rot_const / (constants.k * T))
+    tmp = integrate.quad(f, 0, molecule_num_rot - 1)[0]
+    f = lambda j: (2 * j * (j + 1) * molecule_rot_const * (j - 1) * j * molecule_rot_const
+                   + (j * (j + 1) * molecule_rot_const) ** 2
+                   + ((j - 1) * j * molecule_rot_const) ** 2)\
+                  * ((2.0 * j + 1.0) / molecule_rot_symmetry)\
+                  * np.exp(-j * (j + 1) * molecule_rot_const / (constants.k * T))
+    tmp += integrate.quad(f, 1, molecule_num_rot)[0]
+    if full_integral is False:
+        return tmp * 0.5 / (Z_rot * ((constants.k * T) ** 2) * molecule_num_rot)
+    else:
+        return tmp * 0.5 / (Z_rot * ((constants.k * T) ** 2) * molecule_num_rot)\
+                   * elastic_integral(T, 0, idata, nokt=nokt)
+
+
+def raw_dE_rot_single(T: float, idata: np.ndarray, Z_rot: float, molecule_rot_symmetry: float,
+                      molecule_rot_const: float, molecule_num_rot: int, full_integral: bool=True,
+                      nokt: bool=False) -> float:
+    """Calculates either the partial averaging of the squared change in rotational energy
+    over all one-quantum rotational transitions
+    :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\right>_{part}`
+    or the full averaging of the same quantity :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\right>`,
+    considering all one-quantum transitions to be equiprobable, *raw* version
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    idata : 1-D array-like
+        the array of interaction data
+    Z_rot : float
+        the value of the rotational partition function of the molecule
+    molecule_rot_symmetry : float
+        should equal 2.0 if the molecule is homonuclear and 1.0 otherwise
+    molecule_rot_const : float
+        The quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
+        inertia of the molecule
+    molecule_num_rot : int
+        the amount of rotational levels in the molecule
+    full_integral : bool
+        if True, the full averaging is calculated, if false, the partial averaging is calculated, defaults to True
+    nokt : bool, optional
+        if True and full_integral is True, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to False
+
+    Returns
+    -------
+    float
+        The calculated averaging
+    """
+    f = lambda j: (j * (j + 1) * molecule_rot_const - (j + 1) * (j + 2) * molecule_rot_const)\
+                  * ((2.0 * j + 1.0) / molecule_rot_symmetry)\
+                  * np.exp(-j * (j + 1) * molecule_rot_const / (constants.k * T))
+    tmp = integrate.quad(f, 0, molecule_num_rot - 1)[0]
+    f = lambda j: (j * (j + 1) * molecule_rot_const - (j - 1) * j * molecule_rot_const)\
+                  * ((2.0 * j + 1.0) / molecule_rot_symmetry)\
+                  * np.exp(-j * (j + 1) * molecule_rot_const / (constants.k * T))
+    tmp += integrate.quad(f, 1, molecule_num_rot)[0]
+    if full_integral is False:
+        return tmp * 0.5 / (Z_rot * constants.k * T * molecule_num_rot)
+    else:
+        return tmp * 0.5 / (Z_rot * constants.k * T * molecule_num_rot) * elastic_integral(T, 0, idata, nokt=nokt)
+
+
+def raw_dE_rot_c_dE_rot_d(T: float, idata: np.ndarray, Z_rot1: float, Z_rot2: float, molecule_rot_symmetry1: float,
+                          molecule_rot_symmetry2: float, molecule_rot_const1: float, molecule_rot_const2: float,
+                          molecule_num_rot1: int, molecule_num_rot2: int, full_integral: bool=True,
+                          nokt: bool=False) -> float:
+    """Calculates either the partial averaging of the squared change in rotational energy
+    over all one-quantum rotational transitions
+    :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\Delta \\mathcal{E}^{rot}_{d}\\right>_{part}`
+    or the full averaging of the same quantity
+    :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\Delta \\mathcal{E}^{rot}_{d}\\right>`,
+    considering all one-quantum transitions to be equiprobable, *raw* version
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    idata : 1-D array-like
+        the array of interaction data
+    Z_rot1 : float
+        the value of the rotational partition function of the first molecule
+    Z_rot2 : float
+        the value of the rotational partition function of the second molecule
+    molecule_rot_symmetry1 : float
+        should equal 2.0 if the first molecule is homonuclear and 1.0 otherwise
+    molecule_rot_symmetry2 : float
+        should equal 2.0 if the second molecule is homonuclear and 1.0 otherwise
+    molecule_rot_const1 : float
+        The quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
+        inertia of the first molecule
+    molecule_rot_const2 : float
+        The quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
+        inertia of the second molecule
+    molecule_num_rot1 : int
+        the amount of rotational levels in the first molecule
+    molecule_num_rot2 : int
+        the amount of rotational levels in the second molecule
+    full_integral : bool
+        if True, the full averaging is calculated, if false, the partial averaging is calculated, defaults to True
+    nokt : bool, optional
+        if True and full_integral is True, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to False
+
+    Returns
+    -------
+    float
+        The calculated averaging
+    """
+    return raw_dE_rot_single(T, idata, Z_rot1, molecule_rot_symmetry1, molecule_rot_const1, molecule_num_rot1,
+                             full_integral, nokt) * raw_dE_rot_single(T, idata, Z_rot2, molecule_rot_symmetry2,
+                                                                      molecule_rot_const2, molecule_num_rot2, False,
+                                                                      False)
+
+
+def raw_dE_rot_dE_rot_full(T: float, idata: np.ndarray, Z_rot1: float, Z_rot2: float, molecule_rot_symmetry1: float,
+                           molecule_rot_symmetry2: float, molecule_rot_const1: float, molecule_rot_const2: float,
+                           molecule_num_rot1: int, molecule_num_rot2: int, full_integral: bool=True,
+                           nokt: bool=False) -> float:
+    """Calculates either the partial averaging of the squared change in rotational energy
+    over all one-quantum rotational transitions
+    :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\left(\\Delta \\mathcal{E}^{rot}_{c}
+    + \\Delta \\mathcal{E}^{rot}_{d} \\right)\\right>_{part}`
+    or the full averaging of the same quantity
+    :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\left(\\Delta \\mathcal{E}^{rot}_{c}
+    + \\Delta \\mathcal{E}^{rot}_{d} \\right)\\right>`,
+    considering all one-quantum transitions to be equiprobable, *raw* version
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    idata : 1-D array-like
+        the array of interaction data
+    Z_rot1 : float
+        the value of the rotational partition function of the first molecule
+    Z_rot2 : float
+        the value of the rotational partition function of the second molecule
+    molecule_rot_symmetry1 : float
+        should equal 2.0 if the first molecule is homonuclear and 1.0 otherwise
+    molecule_rot_symmetry2 : float
+        should equal 2.0 if the second molecule is homonuclear and 1.0 otherwise
+    molecule_rot_const1 : float
+        The quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
+        inertia of the first molecule
+    molecule_rot_const2 : float
+        The quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
+        inertia of the second molecule
+    molecule_num_rot1 : int
+        the amount of rotational levels in the first molecule
+    molecule_num_rot2 : int
+        the amount of rotational levels in the second molecule
+    full_integral : bool
+        if True, the full averaging is calculated, if false, the partial averaging is calculated, defaults to True
+    nokt : bool, optional
+        if True and full_integral is True, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to False
+
+    Returns
+    -------
+    float
+        The calculated averaging
+    """
+    return raw_dE_rot_sq(T, idata, Z_rot1, molecule_rot_symmetry1, molecule_rot_const1, molecule_num_rot1,
+                         full_integral, nokt) + raw_dE_rot_single(T, idata, Z_rot1, molecule_rot_symmetry1,
+                                                                  molecule_rot_const1, molecule_num_rot1, full_integral,
+                                                                  nokt) \
+                                                * raw_dE_rot_single(T, idata, Z_rot2, molecule_rot_symmetry2,
+                                                                    molecule_rot_const2, molecule_num_rot2, False,
+                                                                    False)
\ No newline at end of file
