@@ -12,7 +12,7 @@ from csv import reader
 from os.path import normcase, join, split
 from scipy import constants
 from .errors import KineticlibError
-from .particles import Particle
+from .particles import Particle, MoleculeSTS
 
 
 def load_elastic_parameters(partner1: Particle, partner2: Particle) -> np.ndarray:
@@ -80,17 +80,17 @@ def load_elastic_parameters(partner1: Particle, partner2: Particle) -> np.ndarra
     return res
 
 
-def load_dissociation_parameters(molecule_name: str, partner_name: str) -> np.ndarray:
+def load_dissociation_parameters(molecule: MoleculeSTS, partner: Particle) -> np.ndarray:
     """Loads dissociation model parameters for the reaction molecule + partner -> atom1 + atom2 + partner. Loads
     parameters for the Arrhenius model, which is considered to be as follows:
     :math:`k_{diss} = A T^{n}`
 
     Parameters
     ----------
-    molecule_name : str
-        the name of the molecule which dissociates
-    partner_name : str
-        the name of the collision partner
+    molecule_name : MoleculeSTS
+        the molecule which dissociates
+    partner_name : Particle
+        the collision partner
 
     Returns
     -------
@@ -104,6 +104,8 @@ def load_dissociation_parameters(molecule_name: str, partner_name: str) -> np.nd
     KineticlibError
         if no dissociation data is found for these collision partners
     """
+    molecule_name = molecule.name
+    partner_name = partner.name
     this_dir, this_filename = split(__file__)
     csv_file_object = reader(open(join(this_dir, normcase('data/models/dissociation.csv')), 'r'))
     next(csv_file_object)
