@@ -105,6 +105,8 @@ class MoleculeSTS(Particle):
     vibr_model : str
         The model of the vibrational spectrum (can be either 'harmonic', 'anharmonic' or 'table', if pre-calculated
         table values are used for each vibrational level)
+    rot_symmetry : float
+        Equals 2.0 if the molecule is homonuclear and 1.0 otherwise
     num_rot : int
         The amount of rotational levels in the molecule
     num_vibr : int
@@ -334,7 +336,7 @@ class MoleculeSTS(Particle):
         float or 1-D np.ndarray
             The rotational exponent for a given index or set of indices `j`
         """
-        return ((2.0 * j + 1.0) / self.rot_symmetry) * np.exp(-self.rot[j] / (constants.k * T))
+        return ((2.0 * j + 1.0) / self.rot_symmetry) * np.exp(-self.rot_energy(j) / (constants.k * T))
 
     def Z_rot(self, T: float) -> float:
         """Returns the rotational partition function :math:`Z_{rot}(T)`
@@ -516,6 +518,8 @@ class Molecule(MoleculeSTS):
     vibr_model : str
         The model of the vibrational spectrum (can be either 'harmonic', 'anharmonic' or 'table', if pre-calculated
         table values are used for each vibrational level)
+    rot_symmetry : float
+        Equals 2.0 if the molecule is homonuclear and 1.0 otherwise
     num_rot : int
         The amount of rotational levels in the molecule
     num_vibr : int
