@@ -22,7 +22,7 @@ def Y_poly_norm(T: float, T1: float, molecule: Molecule, F: float=0.0) -> float:
         the temperature of the mixture
     T1 : float
         the temperature of the first vibrational level of the molecule for which the polynomial is used
-    molecule : Molecuke
+    molecule : Molecule
         the molecule for which the polynomial is used
     F : float
         the constant appearing in the expression for the polynomial, defaults to 0.0
@@ -52,7 +52,7 @@ def Y_simple_avg(T: float, T1: float, molecule: Molecule, F: float=0.0) -> float
         the temperature of the mixture
     T1 : float
         the temperature of the first vibrational level of the molecule for which the polynomial is used
-    molecule : Molecuke
+    molecule : Molecule
         the molecule for which the polynomial is used
     F : float
         the constant appearing in the expression for the polynomial, defaults to 0.0
